@@ -1,16 +1,16 @@
 let rec token buf =
-  match%sedlex buf with
-  | any -> token buf
-  | eof -> ()
-  | _ -> assert false
+  match%sedlex buf with any -> token buf | eof -> () | _ -> assert false
 
 let time f x =
   let rec acc f x = function
     | 0 -> f x
-    | n -> f x|>ignore; acc f x (n-1) in
-  let t = Sys.time() in
+    | n ->
+        f x |> ignore;
+        acc f x (n - 1)
+  in
+  let t = Sys.time () in
   let fx = acc f x 10 in
-  Printf.printf "Execution time: %fs\n" (Sys.time() -. t);
+  Printf.printf "Execution time: %fs\n" (Sys.time () -. t);
   fx
 
 let () =
@@ -19,4 +19,5 @@ let () =
     let lexbuf = Sedlexing.Latin1.from_string long_str in
     (* let () = Sedlexing.set_curr_p lexbuf Lexing.dummy_pos in *)
     token lexbuf
-  in time token_from long_str
+  in
+  time token_from long_str
